==> open-cluster-management-apps-model-5.12.1-sources.jar: io/fabric8/openclustermanagement/api/model/app/k8s/v1beta1/ConfigMapKeySelectorBuilder.java <==
package io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ConfigMapKeySelectorBuilder extends io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.ConfigMapKeySelectorFluentImpl<io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.ConfigMapKeySelectorBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.ConfigMapKeySelector,io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.ConfigMapKeySelectorBuilder>{
  public ConfigMapKeySelectorBuilder() {
    this(false);
  }
  public ConfigMapKeySelectorBuilder(java.lang.Boolean validationEnabled) {
    this(new ConfigMapKeySelector(), validationEnabled);
  }
  public ConfigMapKeySelectorBuilder(io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.ConfigMapKeySelectorFluent<?> fluent) {
    this(fluent, false);
  }
  public ConfigMapKeySelectorBuilder(io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.ConfigMapKeySelectorFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ConfigMapKeySelector(), validationEnabled);
  }
  public ConfigMapKeySelectorBuilder(io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.ConfigMapKeySelectorFluent<?> fluent,io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.ConfigMapKeySelector instance) {
    this(fluent, instance, false);
  }
  public ConfigMapKeySelectorBuilder(io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.ConfigMapKeySelectorFluent<?> fluent,io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.ConfigMapKeySelector instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withFieldPath(instance.getFieldPath()); 
    fluent.withKey(instance.getKey()); 
    fluent.withKind(instance.getKind()); 
    fluent.withName(instance.getName()); 
    fluent.withNamespace(instance.getNamespace()); 
    fluent.withResourceVersion(instance.getResourceVersion()); 
    fluent.withUid(instance.getUid()); 
    this.validationEnabled = validationEnabled; 
  }
  public ConfigMapKeySelectorBuilder(io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.ConfigMapKeySelector instance) {
    this(instance,false);
  }
  public ConfigMapKeySelectorBuilder(io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.ConfigMapKeySelector instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withFieldPath(instance.getFieldPath()); 
    this.withKey(instance.getKey()); 
    this.withKind(instance.getKind()); 
    this.withName(instance.getName()); 
    this.withNamespace(instance.getNamespace()); 
    this.withResourceVersion(instance.getResourceVersion()); 
    this.withUid(instance.getUid()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.ConfigMapKeySelectorFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.ConfigMapKeySelector build() {
    ConfigMapKeySelector buildable = new ConfigMapKeySelector(fluent.getApiVersion(),fluent.getFieldPath(),fluent.getKey(),fluent.getKind(),fluent.getName(),fluent.getNamespace(),fluent.getResourceVersion(),fluent.getUid());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ConfigMapKeySelectorBuilder that = (ConfigMapKeySelectorBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> open-cluster-management-apps-model-6.6.0-sources.jar: io/fabric8/openclustermanagement/api/model/app/k8s/v1beta1/ConfigMapKeySelectorBuilder.java <==
package io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ConfigMapKeySelectorBuilder extends ConfigMapKeySelectorFluentImpl<ConfigMapKeySelectorBuilder> implements VisitableBuilder<ConfigMapKeySelector,ConfigMapKeySelectorBuilder>{
  public ConfigMapKeySelectorBuilder() {
    this(false);
  }
  public ConfigMapKeySelectorBuilder(Boolean validationEnabled) {
    this(new ConfigMapKeySelector(), validationEnabled);
  }
  public ConfigMapKeySelectorBuilder(ConfigMapKeySelectorFluent<?> fluent) {
    this(fluent, false);
  }
  public ConfigMapKeySelectorBuilder(ConfigMapKeySelectorFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ConfigMapKeySelector(), validationEnabled);
  }
  public ConfigMapKeySelectorBuilder(ConfigMapKeySelectorFluent<?> fluent,ConfigMapKeySelector instance) {
    this(fluent, instance, false);
  }
  public ConfigMapKeySelectorBuilder(ConfigMapKeySelectorFluent<?> fluent,ConfigMapKeySelector instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withFieldPath(instance.getFieldPath()); 
    fluent.withKey(instance.getKey()); 
    fluent.withKind(instance.getKind()); 
    fluent.withName(instance.getName()); 
    fluent.withNamespace(instance.getNamespace()); 
    fluent.withResourceVersion(instance.getResourceVersion()); 
    fluent.withUid(instance.getUid()); 
    this.validationEnabled = validationEnabled; 
  }
  public ConfigMapKeySelectorBuilder(ConfigMapKeySelector instance) {
    this(instance,false);
  }
  public ConfigMapKeySelectorBuilder(ConfigMapKeySelector instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withFieldPath(instance.getFieldPath()); 
    this.withKey(instance.getKey()); 
    this.withKind(instance.getKind()); 
    this.withName(instance.getName()); 
    this.withNamespace(instance.getNamespace()); 
    this.withResourceVersion(instance.getResourceVersion()); 
    this.withUid(instance.getUid()); 
    this.validationEnabled = validationEnabled; 
  }
  ConfigMapKeySelectorFluent<?> fluent;
  Boolean validationEnabled;
  public ConfigMapKeySelector build() {
    ConfigMapKeySelector buildable = new ConfigMapKeySelector(fluent.getApiVersion(),fluent.getFieldPath(),fluent.getKey(),fluent.getKind(),fluent.getName(),fluent.getNamespace(),fluent.getResourceVersion(),fluent.getUid());
    return buildable;
  }
  
}
